@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2009-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -58,13 +58,14 @@ int
 main (int argc, char **argv)
 {
 	gboolean ret;
-	gchar *copyright = NULL;
-	gchar *description = NULL;
+	const gchar *copyright;
+	const gchar *description;
 	GFile *destination = NULL;
 	GFile *file = NULL;
 	gchar **files = NULL;
 	guint retval = 1;
 	GcmProfile *profile = NULL;
+	GcmColorspace colorspace;
 	GError *error = NULL;
 	GOptionContext *context;
 	GString *string = NULL;
@@ -125,13 +126,14 @@ main (int argc, char **argv)
 	}
 
 	/* get data */
+	description = gcm_profile_get_description (profile);
+	copyright = gcm_profile_get_copyright (profile);
+	colorspace = gcm_profile_get_colorspace (profile);
 	g_object_get (profile,
-		      "description", &description,
-		      "copyright", &copyright,
-		      "white-point", &white,
-		      "luminance-red", &red,
-		      "luminance-green", &green,
-		      "luminance-blue", &blue,
+		      "white", &white,
+		      "red", &red,
+		      "green", &green,
+		      "blue", &blue,
 		      NULL);
 
 	/* use CIE widget */
@@ -188,6 +190,10 @@ main (int argc, char **argv)
 	/* add cie widget */
 	gcm_import_add_cie_widget (GTK_DIALOG(dialog), cie_widget);
 
+	/* only show the cie widget if we have RGB data */
+	if (colorspace != GCM_COLORSPACE_RGB)
+		gtk_widget_hide (cie_widget);
+
 	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -233,8 +239,6 @@ out:
 		g_object_unref (profile);
 	if (destination != NULL)
 		g_object_unref (destination);
-	g_free (description);
-	g_free (copyright);
 	g_strfreev (files);
 	return retval;
 }
